##  Step 3. Report and Communicate
During your transformation, you will constantly evolve the [dashboards you built in phase 1 (Prepare)](https://help.sap.com/docs/leanix/ea/erp-transformation-discover?locale=en-US&state=PRODUCTION&version=CLOUD "Establish architecture transparency in ERP transformation. Understand and assess your 'as-is architecture' and report effectively.") and add new reports and KPIs. The following views show examples of reports and KPIs that you can include in this phase to show the results of your analyses and track key KPIs that are important for the preparation of the transformation.
![Dashboard for Phase 2 \(Prepare\)](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2748d51e7a441014ac9ad56ad17cc6f0_LowRes.gif)
Illustrative Dashboard for Phase 2 (Prepare)
In the Discover phase, we suggest including the following metrics that can be set up with SAP LeanIX KPIs and presented in a SAP LeanIX Dashboard:
  * Overview of ERP Initiatives and which Objectives and Business Capabilities are supported: Matrix Report showing an overview of your ERP Initiatives clustered by Objectives and Business Capabilities. This view is a good summary of the strategic elements of your ERP transformation and helps align your Initiative/Program with your organization’s objectives and capabilities. It also shows gaps, where certain Business Capabilities/Objectives don’t have specific Initiatives aligned to realize them.
![Overview of ERP Initiatives showing supported Objectives and Business Capabilities](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2747fdc97a441014bbb3e0a71facd9b5_LowRes.png)
Overview of ERP Initiatives showing supported Objectives and Business Capabilities
  * Initiative Data Quality: Overview of KPIs providing a first high-level overview of the number of Initiatives that have been scoped to support the ERP Transformation, and for how many of those Initiatives mandatory attributes have been filled/assessed (Responsibles, Lifecycles, Business Risks).
![Initiative Data Quality](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2749a45d7a441014b898e6f66dbdebd0_LowRes.png)
Initiative Data Quality
  * ERP Roadmap with Initiatives and Milestones: Roadmap Report providing a high-level overview of the ERP transformation timeline, different projects, and Milestones (only visible with activated SAP LeanIX Architecture and Road Map Planning).
![ERP Roadmap with Initiatives and Milestones](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274da9707a441014b776d73460875843_LowRes.png)
ERP Roadmap with Initiatives and Milestones


Follow the best practices on reporting and communicating from [Phase 1 (Discover)](https://help.sap.com/docs/leanix/ea/erp-transformation-discover?locale=en-US&state=PRODUCTION&version=CLOUD "Establish architecture transparency in ERP transformation. Understand and assess your 'as-is architecture' and report effectively."). Make sure that about 90% of your business stakeholders have seen and acknowledged your insights and recommendations.
